@@ -31,6 +31,8 @@ if (base::getRversion() >= "2.15.1") {
     "diff.sq", "nEffective", "now.negative", "phat", "psum", "psum.negative", "sum.diff.sq",
     "sum.phat", "variogram", # from ggs_effective()
     "second.half", # from ggs(), splitting
-    "browseURL" # from utils, for ggmcmc()
+    "browseURL", # from utils, for ggmcmc()
+    "E", "Effective", # in ggs_effective()
+    "Diagnostic" # in ggs_diagnostics()
   ))
 }
